<?php 

/**
 * Build theme options
 * Uses the Ebor_Options class found in the ebor-framework plugin
 * Panels are WP 4.0+!!!
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if( class_exists('Ebor_Options') ){
	$ebor_options = new Ebor_Options;
	
	/**
	 * Variables
	 */
	$theme = wp_get_theme();
	$theme_name = $theme->get( 'Name' );
	$header_layouts = ebor_get_header_options();
	
	$social_options = ebor_get_icons();
	foreach( $social_options as $social ){
		$new_social_options[$social] = ucfirst(str_replace('ti-', '', $social));	
	}
	
	/**
	 * Default stuff
	 * 
	 * Each of these is a default option that appears in each theme, demo data, favicons and a custom css input
	 * 
	 * @since 1.0.0
	 * @author tommusrhodus
	 */
	$ebor_options->add_panel( $theme_name . ': Demo Data', 5, '');
	$ebor_options->add_panel( $theme_name . ': Styling Settings', 205, 'All of the controls in this section directly relate to the styling page of ' . $theme_name);
	$ebor_options->add_section('demo_data_section', 'Import Demo Data', 10, $theme_name . ': Demo Data', '<strong>Please read this before importing demo data via this control:</strong><br /><br />The demo data this will install includes images from my demo site with <strong>heavy blurring applied</strong> this is due to licensing restrictions. Simply replace these images with your own.<br /><br />Note that this process can take up to 15mins on slower servers, go make a cup of tea. If you havn\'t had a notification in 30mins, use the fallback method outlined in the written documentation.<br /><br />');
	$ebor_options->add_section('custom_css_section', 'Custom CSS', 40, $theme_name . ': Styling Settings');
	$ebor_options->add_setting('demo_import', 'demo_import', 'Import Demo Data', 'demo_data_section', '', 10);
	$ebor_options->add_setting('textarea', 'custom_css', 'Custom CSS', 'custom_css_section', '', 30);
	
	//Panels
	$ebor_options->add_panel( $theme_name . ': Header Settings', 215, 'All of the controls in this section directly relate to the header and logos of ' . $theme_name);
	
	/**
	 * Instagram API Stuff
	 */
	$ebor_options->add_section('instagram_api_section', $theme_name . ': Instagram Settings', 340, false, '<code>IMPORTANT NOTE:</code> This is the Instagram setup section for the theme, it requires an Access Token and Client ID.<br /><br />Due to how Instagram have set their API you have to register as a developer with Instagram for this to work.<br /><br />For setup details, <a href="https://tommusrhodus.ticksy.com/article/7566" target="_blank">please read this</a>');
	$ebor_options->add_setting('input', 'instagram_token', 'Instagram Access Token', 'instagram_api_section', '', 5);
	$ebor_options->add_setting('input', 'instagram_client', 'Instagram Client ID', 'instagram_api_section', '', 10);
	
	//Header Settings
	$ebor_options->add_section('header_layout_section', 'Header Layout', 5, $theme_name . ': Header Settings', '<strong>Welcome to the header settings</strong><br /><br />Use the header layout control to control what header you want to see sitewide.<br /><br />Show Header Bar at Top controls whether you see the additional texts & social icons at the top of your page.<br /><br />Header background image is for the image background header layout only.<br /><br />If your page jumps or flickers as you scroll down the screen, adjust the nav min height control to fix this. The mobile nav min height control ensures that your header is the correct size on mobile, this can be adjusted to adjust the distance between the header and your content as needed.');
	$ebor_options->add_section('logo_settings_section', 'Logo Settings', 10, $theme_name . ': Header Settings');
	$ebor_options->add_section('header_text_section', 'Header Texts', 15, $theme_name . ': Header Settings');
	$ebor_options->add_section('sub_header_layout_section', 'Sub Header Settings', 20, $theme_name . ': Header Settings', 'This setting controls the theme header site-wide. If you need to you can override this setting on specific posts and pages from within that posts edit screen.');
	
	//Post Settings
	$ebor_options->add_section('post_layout_section', $theme_name . ': Post Social Icons', 215, false);
	
	for( $i = 1; $i < 5; $i++ ){
		$ebor_options->add_setting('select', 'post_social_icon_' . $i, 'Post Social Icon ' . $i, 'post_layout_section', 'none', 30 + $i + $i, $new_social_options);
		$ebor_options->add_setting('input', 'post_social_url_' . $i, 'Post Social URL ' . $i, 'post_layout_section', '', 31 + $i + $i);
	}
	
	//Colours
	$ebor_options->add_setting('color', 'padre_colour_white', 'Light Wrapper Colour', 'colors', '#FFFFFF', 1);
	$ebor_options->add_setting('color', 'padre_colour_secondary', 'Dark Wrapper Colour', 'colors', '#f8f8f8', 5);
	$ebor_options->add_setting('color', 'padre_colour_dark', 'Black Wrapper Colour', 'colors', '#292929', 7);
	$ebor_options->add_setting('color', 'padre_colour_primary', 'Highlight Colour', 'colors', '#25262e', 10);
	$ebor_options->add_setting('color', 'padre_colour_lightgrey', 'Body Font Colour', 'colors', '#666666', 15);
	$ebor_options->add_setting('color', 'padre_colour_lightblack', 'Headings Font Colour', 'colors', '#222222', 20);
	$ebor_options->add_setting('color', 'padre_colour_red', 'Red Colour', 'colors', '#e31d3b', 25);
	$ebor_options->add_setting('color', 'padre_colour_darkgrey', 'Dark Grey Colour', 'colors', '#cccccc', 30);
	$ebor_options->add_setting('color', 'padre_colour_body', 'Body Colour', 'colors', '#faf9f6', 35);
	$ebor_options->add_setting('color', 'padre_colour_copy', 'Copy Colour', 'colors', '#333333', 40);
	
	//Header Texts
	$ebor_options->add_setting('input', 'header_left', 'Left Header Text', 'header_text_section', '42 Orchard St. Armadale 3143', 5);
	$ebor_options->add_setting('input', 'header_right', 'Right Header Text', 'header_text_section', 'Open Daily: 7am - 4pm', 10);
	
	$ebor_options->add_setting('select', 'header_layout', 'Global Header Layout', 'header_layout_section', 'standard', 5, $header_layouts);
	$ebor_options->add_setting('select', 'header_utility', 'Show header top bar?', 'header_layout_section', 'yes', 7, array('yes' => 'Yes', 'no' => 'No'));
	$ebor_options->add_setting('image', 'header_background', 'Image Header Background Image', 'header_layout_section', EBOR_THEME_DIRECTORY . 'style/img/home2.jpg', 10);
	$ebor_options->add_setting('range', 'nav_min_height', 'Nav Min Height (491 Default)', 'header_layout_section', '491', 15, array('min' => '300', 'max' => '700', 'step' => '1'));
	$ebor_options->add_setting('range', 'mobile_nav_min_height', 'Mobile Nav Min Height (366 Default)', 'header_layout_section', '366', 20, array('min' => '200', 'max' => '500', 'step' => '1'));
	
	//Logo Options
	$ebor_options->add_setting('image', 'custom_logo', 'Logo', 'logo_settings_section', EBOR_THEME_DIRECTORY . 'style/img/logo-dark.png', 5);
	$ebor_options->add_setting('image', 'custom_logo_light', 'Light Logo', 'logo_settings_section', EBOR_THEME_DIRECTORY . 'style/img/logo-light.png', 10);
	$ebor_options->add_setting('range', 'logo_height', 'Logo Max Height (175 Default)', 'logo_settings_section', '175', 15, array('min' => '100', 'max' => '300', 'step' => '1'));
	
	//Header icons
	for( $i = 1; $i < 5; $i++ ){
		$ebor_options->add_setting('select', 'header_social_icon_' . $i, 'Header Social Icon ' . $i, 'sub_header_layout_section', 'none', 30 + $i + $i, $new_social_options);
		$ebor_options->add_setting('input', 'header_social_url_' . $i, 'Header Social URL ' . $i, 'sub_header_layout_section', '', 31 + $i + $i);
	}

}