<?php 

/**
 * Here is all the custom colours for the theme.
 * $handle is a reference to the handle used with wp_enqueue_style()
 */
if(!( function_exists('ebor_less_vars') )){ 
	function ebor_less_vars( $vars, $handle = 'ebor-theme-styles' ) {
		$vars['white']           = get_option('padre_colour_white', '#fff');
		$vars['red']             = get_option('padre_colour_red', '#e31d3b');
		$vars['color-primary']   = get_option('padre_colour_primary', '#25262e');
		$vars['bg-secondary']    = get_option('padre_colour_secondary', '#f8f8f8');
		$vars['bg-dark']         = get_option('padre_colour_dark', '#292929');
		$vars['color-body']      = get_option('padre_colour_body', '#faf9f6');
		$vars['darkgrey']        = get_option('padre_colour_darkgrey', '#ccc');
		$vars['lightgrey']       = get_option('padre_colour_lightgrey', '#666');
		$vars['lightblack']      = get_option('padre_colour_lightblack', '#222');
		$vars['copy']            = get_option('padre_colour_copy', '#333');
		$vars['nav-height']      = (int) get_option('nav_height','55') . 'px';
		$vars['nav-line-height'] = (int) get_option('nav_line_height','53') . 'px';
	    return $vars;
	}
	add_filter( 'less_vars', 'ebor_less_vars', 10, 2 );
}

/*
Register Fonts
*/
if(!( function_exists('ebor_fonts_url') )){
	function ebor_fonts_url(){
	    $font_url = '';
	    
	    /*
	    	Translators: If there are characters in your language that are not supported
	   		by chosen font(s), translate this to 'off'. Do not translate into your own language.
	     */
	    if ( 'off' !== _x( 'on', 'Google font: on or off', 'padre' ) ) {
	        $font_url = add_query_arg( 'family', urlencode( 'Pathway Gothic One|Montserrat|Inconsolata:400,700' ), "//fonts.googleapis.com/css" );
	    }
	    return $font_url;
	}
}

/**
 * Ebor Load Scripts
 * Properly Enqueues Scripts & Styles for the theme
 * @since version 1.0
 * @author TommusRhodus
 */ 
if(!( function_exists('ebor_load_scripts') )){
	function ebor_load_scripts() {
			
		//Enqueue Styles
		wp_enqueue_style( 'ebor-google-font', ebor_fonts_url(), array(), '1.0.0' );
		wp_enqueue_style( 'ebor-bootstrap', EBOR_THEME_DIRECTORY . 'style/css/bootstrap.css' );
		wp_enqueue_style( 'ebor-fonts', EBOR_THEME_DIRECTORY . 'style/css/fonts.css' );	
		wp_enqueue_style( 'ebor-theme-styles', EBOR_THEME_DIRECTORY . 'style/css/theme.less' );
		wp_enqueue_style( 'ebor-style', get_stylesheet_uri() );
		
		//Enqueue Scripts
		wp_enqueue_script( 'ebor-bootstrap', EBOR_THEME_DIRECTORY . 'style/js/bootstrap.min.js', array('jquery'), false, true  );
		wp_enqueue_script( 'ebor-plugins', EBOR_THEME_DIRECTORY . 'style/js/plugins.js', array('jquery'), false, true  );
		wp_enqueue_script( 'ebor-scripts', EBOR_THEME_DIRECTORY . 'style/js/scripts.js', array('jquery'), false, true  );
		
		//Enqueue Comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
		
		$custom_css = get_option('custom_css');
		
		$custom_css .= '
			.logo { max-height: '. (int) get_option('logo_height', '175') .'px; }
			
			.nav-container {
				min-height: '. (int) get_option('nav_min_height', '491') .'px;
			}
			
			.admin-bar .nav-container {
				min-height: '. ( (int) get_option('nav_min_height', '491') + 32 ) .'px;
			}
			
			@media all and (max-width: 767px){
				.nav-container {
					min-height: '. (int) get_option('mobile_nav_min_height', '366') .'px;
				}
				
				.admin-bar .nav-container {
					min-height: '. ( (int) get_option('mobile_nav_min_height', '366')  + 32 ) .'px;
				}
			}
		';
		
		//Add custom CSS ability
		wp_add_inline_style( 'ebor-style', $custom_css );
		
		/**
		 * localize script
		 */
		$script_data = array( 
			'access_token'       => get_option('instagram_token', ''),
			'client_id'          => get_option('instagram_client', '')
		);
		wp_localize_script( 'ebor-scripts', 'wp_data', $script_data );
		
	}
	add_action('wp_enqueue_scripts', 'ebor_load_scripts', 110);
}

/**
 * Ebor Load Admin Scripts
 * Properly Enqueues Scripts & Styles for the theme
 * 
 * @since version 1.0
 * @author TommusRhodus
 */
if(!( function_exists('ebor_admin_load_scripts') )){
	function ebor_admin_load_scripts(){
		wp_enqueue_style( 'ebor-theme-admin-css', EBOR_THEME_DIRECTORY . 'admin/ebor-theme-admin.css' );
		wp_enqueue_style( 'ebor-fonts', EBOR_THEME_DIRECTORY . 'style/css/fonts.css' );	
	}
	add_action('admin_enqueue_scripts', 'ebor_admin_load_scripts', 200);
}