<?php 

/**
 * Force Visual Composer to initialize as "built into the theme". This will hide certain tabs under the Settings->Visual Composer page
 */
if( function_exists('vc_set_as_theme') ){
	function ebor_vcSetAsTheme() {
		vc_set_as_theme(true);
	}
	add_action( 'vc_before_init', 'ebor_vcSetAsTheme' );
}

if(!( function_exists('ebor_custom_css_classes_for_vc_row_and_vc_column') )){
	function ebor_custom_css_classes_for_vc_row_and_vc_column( $class_string, $tag ) {
		if ( $tag == 'vc_column' || $tag == 'vc_column_inner' ) {
			$class_string = preg_replace( '/vc_col-sm-(\d{1,2})/', 'col-md-$1', $class_string );
		}
		return $class_string;
	}
	add_filter( 'vc_shortcodes_css_class', 'ebor_custom_css_classes_for_vc_row_and_vc_column', 10, 2 );
}

/**
 * Add additional functions to certain blocks.
 * vc_map runs before custom post types and taxonomies are created, so this function is used
 * to add custom taxonomy selectors to VC blocks, a little annoying, but works perfectly.
 */
if(!( function_exists('ebor_vc_add_att') )){
	function ebor_vc_add_attr(){
		
		$attributes = array(
			"type" => "textarea_html",
			"heading" => esc_html__("Block Content", 'padre'),
			"param_name" => "content",
			'holder' => 'div'
		);
		vc_add_param('vc_gmaps', $attributes);
		
		/**
		 * Add menu category selectors
		 */
		$menu_args = array(
			'orderby'                  => 'name',
			'hide_empty'               => 0,
			'hierarchical'             => 1,
			'taxonomy'                 => 'menu_category'
		);
		$menu_cats = get_categories( $menu_args );
		$final_menu_cats = array( 'Show all categories' => 'all' );
		
		if( taxonomy_exists('menu_category') ){
			if( is_array($menu_cats) ){
				foreach( $menu_cats as $cat ){
					$final_menu_cats[$cat->name] = $cat->term_id;
				}
			}
		}
		
		$attributes = array(
			'type' => 'dropdown',
			'heading' => "Show Specific menu Category?",
			'param_name' => 'filter',
			'value' => $final_menu_cats
		);
		vc_add_param('padre_menu', $attributes);

		vc_remove_param('vc_gmaps', 'title');
		vc_remove_param('vc_gmaps', 'size');
		vc_remove_param('vc_gmaps', 'el_class');
		
	}
	add_action('init', 'ebor_vc_add_attr', 999);
}

/**
 * Redirect page template if vc_row shortcode is found in the page.
 * This lets us use a dedicated page template for Visual Composer pages
 * without the need for on page checks, or custom page templates.
 * 
 * It's buyer-proof basically.
 */
if(!( function_exists('ebor_vc_page_template') )){
	function ebor_vc_page_template( $template ){
		global $post;
		
		if( is_archive() || is_404() )
			return $template;
		
		if(!( isset($post->post_content) ) || is_search())
			return $template;
			
		if( has_shortcode($post->post_content, 'vc_row') ){
			$new_template = locate_template( array( 'page_visual_composer.php' ) );
			if (!( '' == $new_template )){
				return $new_template;
			}
		}
		return $template;
	}
	add_filter( 'template_include', 'ebor_vc_page_template', 99 );
}

/**
 * Page builder blocks below here
 * Whoop-dee-doo
 */
get_template_part('vc_blocks/vc_section_title_block');
get_template_part('vc_blocks/vc_menu_block');
get_template_part('vc_blocks/vc_instagram_block');
get_template_part('vc_blocks/vc_testimonial_block');